@@ -4,7 +4,6 @@ import (
 	"bufio"
 	"fmt"
 	"io"
-	"io/fs"
 	"io/ioutil"
 	"log"
 	"net/url"
@@ -474,7 +473,7 @@ func sanitizePath(p string) string {
 	}
 	if isDir {
 		p += "/"
-	} else if info, err := os.Lstat(p); err == nil && info.Mode().IsDir() && info.Mode()&fs.ModeSymlink == 0 {
+	} else if info, err := os.Lstat(p); err == nil && info.Mode().IsDir() && info.Mode()&os.ModeSymlink == 0 {
 		p += "/"
 	}
 	if isCur {
@@ -500,23 +499,23 @@ func fileMatches(filename string) bool {
 	return true
 }
 
-type DirEntry struct {
-	fs.FileInfo
-}
-
-func (d DirEntry) Type() fs.FileMode {
-	return d.Mode().Type()
-}
-
-func (d DirEntry) Info() (fs.FileInfo, error) {
-	return d.FileInfo, nil
-}
+//type DirEntry struct {
+//	fs.FileInfo
+//}
+//
+//func (d DirEntry) Type() fs.FileMode {
+//	return d.Mode().Type()
+//}
+//
+//func (d DirEntry) Info() (fs.FileInfo, error) {
+//	return d.FileInfo, nil
+//}
 
 func createTasks(inputs []string, output string) ([]Task, []string, error) {
 	tasks := []Task{}
 	roots := []string{}
 	for _, input := range inputs {
-		var info fs.FileInfo
+		var info os.FileInfo
 		var err error
 		if !preserveSymlinks {
 			info, err = os.Stat(input)
@@ -527,7 +526,7 @@ func createTasks(inputs []string, output string) ([]Task, []string, error) {
 			return nil, nil, err
 		}
 
-		if info.Mode()&fs.ModeSymlink != 0 {
+		if info.Mode()&os.ModeSymlink != 0 {
 			if !sync {
 				Warning.Println("--sync not specified, omitting symbolic link", input)
 				continue
@@ -553,33 +552,33 @@ func createTasks(inputs []string, output string) ([]Task, []string, error) {
 			}
 			roots = append(roots, input)
 
-			var walkFn func(string, fs.DirEntry, error) error
-			walkFn = func(path string, d fs.DirEntry, err error) error {
+			var walkFn func(string, DirEntry, error) error
+			walkFn = func(path string, d DirEntry, err error) error {
 				if err != nil {
 					return err
 				} else if d.Name() == "." || d.Name() == ".." {
 					return nil
-				} else if len(d.Name()) == 0 || !hidden && d.Name()[0] == '.' {
+				} else if d.Name() == "" || !hidden && d.Name()[0] == '.' {
 					if d.IsDir() {
-						return fs.SkipDir
+						return SkipDir
 					}
 					return nil
 				}
 				path = sanitizePath(path)
 
-				if !preserveSymlinks && d.Type()&fs.ModeSymlink != 0 {
+				if !preserveSymlinks && d.Type()&os.ModeSymlink != 0 {
 					// follow and dereference symlinks
 					info, err := os.Stat(path)
 					if err != nil {
 						return err
 					}
 					if info.IsDir() {
-						return fs.WalkDir(os.DirFS(input), path, walkFn)
+						return WalkDir(DirFS(input), path, walkFn)
 					}
-					d = DirEntry{info}
+					d = &statDirEntry{info}
 				}
 
-				if preserveSymlinks && d.Type()&fs.ModeSymlink != 0 {
+				if preserveSymlinks && d.Type()&os.ModeSymlink != 0 {
 					// copy symlinks as is
 					if !sync {
 						Warning.Println("--sync not specified, omitting symbolic link", path)
@@ -602,7 +601,7 @@ func createTasks(inputs []string, output string) ([]Task, []string, error) {
 				}
 				return nil
 			}
-			if err := fs.WalkDir(os.DirFS("."), path.Clean(input), walkFn); err != nil {
+			if err := WalkDir(DirFS("."), path.Clean(input), walkFn); err != nil {
 				return nil, nil, err
 			}
 		} else {
@@ -669,7 +668,7 @@ func minify(t Task) bool {
 	if t.sync {
 		if t.srcs[0] == t.dst {
 			return true
-		} else if info, err := os.Lstat(t.srcs[0]); preserveSymlinks && err == nil && info.Mode()&fs.ModeSymlink != 0 {
+		} else if info, err := os.Lstat(t.srcs[0]); preserveSymlinks && err == nil && info.Mode()&os.ModeSymlink != 0 {
 			src, err := os.Readlink(t.srcs[0])
 			if err != nil {
 				Error.Println(err)
@@ -683,12 +682,6 @@ func minify(t Task) bool {
 		}
 	}
 
-	srcInfo, err := os.Stat(t.srcs[0])
-	if err != nil {
-		Error.Println(err)
-		return false
-	}
-
 	fileMimetype := mimetype
 	if mimetype == "" && !t.sync {
 		for _, src := range t.srcs {
@@ -753,7 +746,14 @@ func minify(t Task) bool {
 		return false
 	}
 
-	os.Chmod(t.dst, srcInfo.Mode().Perm())
+	if t.srcs[0] != "" {
+		srcInfo, err := os.Stat(t.srcs[0])
+		if err != nil {
+			Error.Println(err)
+			return false
+		}
+		os.Chmod(t.dst, srcInfo.Mode().Perm())
+	}
 
 	// synchronize file
 	if t.sync {
