@@ -398,7 +398,7 @@ func (c *cssMinifier) minifyDeclaration(property []byte, components []css.Token)
 		return
 	}
 
-	values = c.minifyTokens(prop, values)
+	values = c.minifyTokens(prop, 0, values)
 	if len(values) > 0 {
 		values = c.minifyProperty(prop, values)
 	}
@@ -440,7 +440,7 @@ func (c *cssMinifier) writeDeclaration(values []Token, important bool) {
 	}
 }
 
-func (c *cssMinifier) minifyTokens(prop Hash, values []Token) []Token {
+func (c *cssMinifier) minifyTokens(prop Hash, fun Hash, values []Token) []Token {
 	for i, value := range values {
 		tt := value.TokenType
 		switch tt {
@@ -464,7 +464,7 @@ func (c *cssMinifier) minifyTokens(prop Hash, values []Token) []Token {
 		case css.DimensionToken:
 			var dim []byte
 			values[i], dim = c.minifyDimension(values[i])
-			if 1 < len(values[i].Data) && values[i].Data[0] == '0' && optionalZeroDimension[string(dim)] && prop != Flex && prop != Function {
+			if 1 < len(values[i].Data) && values[i].Data[0] == '0' && optionalZeroDimension[string(dim)] && prop != Flex && fun == 0 {
 				// cut dimension for zero value, TODO: don't hardcode check for Flex and remove the dimension in minifyDimension
 				values[i].Data = values[i].Data[:1]
 			}
@@ -489,7 +489,7 @@ func (c *cssMinifier) minifyTokens(prop Hash, values []Token) []Token {
 				}
 			}
 		case css.FunctionToken:
-			values[i].Args = c.minifyTokens(Function, values[i].Args)
+			values[i].Args = c.minifyTokens(prop, values[i].Fun, values[i].Args)
 
 			fun := values[i].Fun
 			args := values[i].Args
@@ -1096,9 +1096,11 @@ func (c *cssMinifier) minifyProperty(prop Hash, values []Token) []Token {
 		values[0] = minifyColor(values[0])
 	case Background_Color:
 		values[0] = minifyColor(values[0])
-		if values[0].Ident == Transparent {
-			values[0].Data = initialBytes
-			values[0].Ident = Initial
+		if !c.o.KeepCSS2 {
+			if values[0].Ident == Transparent {
+				values[0].Data = initialBytes
+				values[0].Ident = Initial
+			}
 		}
 	case Border_Color:
 		sameValues := true
@@ -1173,26 +1175,24 @@ func (c *cssMinifier) minifyProperty(prop Hash, values []Token) []Token {
 			}
 		} else if len(values) == 3 && values[0].TokenType == css.NumberToken && values[1].TokenType == css.NumberToken {
 			if len(values[0].Data) == 1 && len(values[1].Data) == 1 {
-				grow := values[0].Data[0] == '1'
-				shrink := values[1].Data[0] == '1'
 				if values[2].Ident == Auto {
-					if !grow && shrink {
+					if values[0].Data[0] == '0' && values[1].Data[0] == '1' {
 						values = values[:1]
 						values[0].TokenType = css.IdentToken
 						values[0].Data = initialBytes
 						values[0].Ident = Initial
-					} else if grow && shrink {
+					} else if values[0].Data[0] == '1' && values[1].Data[0] == '1' {
 						values = values[:1]
 						values[0].TokenType = css.IdentToken
 						values[0].Data = autoBytes
 						values[0].Ident = Auto
-					} else if !grow && !shrink {
+					} else if values[0].Data[0] == '0' && values[1].Data[0] == '0' {
 						values = values[:1]
 						values[0].TokenType = css.IdentToken
 						values[0].Data = noneBytes
 						values[0].Ident = None
 					}
-				} else if shrink && values[2].IsZero() {
+				} else if values[1].Data[0] == '1' && values[2].IsZero() {
 					values = values[:1] // remove <flex-shrink> and <flex-basis> if they are 1 and 0 respectively
 				} else if values[2].IsZero() {
 					values = values[:2] // remove auto to write 2-value syntax of <flex-grow> <flex-shrink>
