@@ -25,7 +25,6 @@ var (
 	openBracketBytes           = []byte("[")
 	closeBracketBytes          = []byte("]")
 	openParenBracketBytes      = []byte("({")
-	closeBracketParenBytes     = []byte("})")
 	closeParenOpenBracketBytes = []byte("){")
 	notBytes                   = []byte("!")
 	questionBytes              = []byte("?")
@@ -34,7 +33,6 @@ var (
 	andBytes                   = []byte("&&")
 	orBytes                    = []byte("||")
 	optChainBytes              = []byte("?.")
-	nullishBytes               = []byte("??")
 	arrowBytes                 = []byte("=>")
 	zeroBytes                  = []byte("0")
 	oneBytes                   = []byte("1")
@@ -72,8 +70,6 @@ var (
 	openNewBytes               = []byte("(new")
 	newTargetBytes             = []byte("new.target")
 	importMetaBytes            = []byte("import.meta")
-	varBytes                   = []byte("var")
-	varSpaceBytes              = []byte("var ")
 	nanBytes                   = []byte("NaN")
 	undefinedBytes             = []byte("undefined")
 	infinityBytes              = []byte("Infinity")
@@ -85,7 +81,6 @@ var (
 	groupedNotZeroBytes        = []byte("(!0)")
 	notOneBytes                = []byte("!1")
 	groupedNotOneBytes         = []byte("(!1)")
-	useStrictBytes             = []byte(`"use strict"`)
 	debuggerBytes              = []byte("debugger")
 )
 
