@@ -13,10 +13,12 @@ type Token struct {
 	Data    []byte
 	Text    []byte
 	AttrVal []byte
+	Offset  int
 }
 
 // TokenBuffer is a buffer that allows for token look-ahead.
 type TokenBuffer struct {
+	r *parse.Input
 	l *xml.Lexer
 
 	buf []Token
@@ -26,19 +28,23 @@ type TokenBuffer struct {
 }
 
 // NewTokenBuffer returns a new TokenBuffer.
-func NewTokenBuffer(l *xml.Lexer) *TokenBuffer {
+func NewTokenBuffer(r *parse.Input, l *xml.Lexer) *TokenBuffer {
 	return &TokenBuffer{
+		r:   r,
 		l:   l,
 		buf: make([]Token, 0, 8),
 	}
 }
 
 func (z *TokenBuffer) read(t *Token) {
+	t.Offset = z.r.Offset()
 	t.TokenType, t.Data = z.l.Next()
 	t.Text = z.l.Text()
 	if t.TokenType == xml.AttributeToken {
+		t.Offset += 1 + len(t.Text) + 1
 		t.AttrVal = z.l.AttrVal()
 		if len(t.AttrVal) > 1 && (t.AttrVal[0] == '"' || t.AttrVal[0] == '\'') {
+			t.Offset++
 			t.AttrVal = t.AttrVal[1 : len(t.AttrVal)-1] // quotes will be readded in attribute loop if necessary
 			t.AttrVal = parse.ReplaceMultipleWhitespaceAndEntities(t.AttrVal, minifyXML.EntitiesMap, nil)
 			t.AttrVal = parse.TrimWhitespace(t.AttrVal)
